window.Gleam.initSearch([{"doc":"franz","title":"franz","content":"# franz\n\n[![Package Version](https://img.shields.io/hexpm/v/franz)](https://hex.pm/packages/franz)\n[![Hex Docs](https://img.shields.io/badge/hex-docs-ffaff3)](https://hexdocs.pm/franz/)\n\n`franz` is a Gleam library for interacting with Kafka. It provides functionalities to produce and consume messages, handle topics, and manage configurations.\n\n## Installation\n\nAdd `franz` to your Gleam project:\n\n```sh\ngleam add franz\n```\n\n## Usage\n\n```gleam\n  import franz\n  import franz/consumers\n  import franz/producers\n\n  let topic = &quot;gleamy_topic&quot;\n  let endpoint = #(&quot;localhost&quot;, 9092)\n  let assert Ok(connection) =\n    franz.start_client([endpoint], [franz.AutoStartProducers(True)])\n\n  let assert Ok(Nil) = franz.create_topic([endpoint], topic, 1, 1)\n\n  let assert Ok(Nil) =\n    producers.produce_sync(\n      connection,\n      topic,\n      producers.Partitioner(producers.Random),\n      &lt;&lt;&quot;gracias&quot;&gt;&gt;,\n      producers.Value(&lt;&lt;&quot;bitte&quot;&gt;&gt;, [#(&quot;meta&quot;, &quot;data&quot;)]),\n    )\n\n  let counter = 0\n  let assert Ok(pid) =\n    consumers.start_group_subscriber(\n      connection,\n      &quot;group&quot;,\n      [topic],\n      [consumers.BeginOffset(consumers.Earliest)],\n      [consumers.OffsetCommitIntervalSeconds(5)],\n      consumers.Message,\n      fn(message, counter) {\n        // io.debug(message)\n        // io.debug(counter)\n        consumers.commit_return(counter + 1)\n      },\n      counter,\n    )\n```\n","url":"index.html"},{"doc":"franz","title":"ClientConfig","content":"pub type ClientConfig {\n  RestartDelaySeconds(Int)\n  GetMetadataTimeoutSeconds(Int)\n  ReconnectCoolDownSeconds(Int)\n  AllowTopicAutoCreation(Bool)\n  AutoStartProducers(Bool)\n  DefaultProducerConfig(List(ProducerConfig))\n  UnknownTopicCacheTtl(Int)\n}\n\nRestartDelaySeconds(Int)\n\n\nGetMetadataTimeoutSeconds(Int)\n\n\nReconnectCoolDownSeconds(Int)\n\n\nAllowTopicAutoCreation(Bool)\n\n\nAutoStartProducers(Bool)\n\n\nDefaultProducerConfig(List(ProducerConfig))\n\n\nUnknownTopicCacheTtl(Int)\n\n\nSynonyms:\nfranz.ClientConfig\nfranz ClientConfig","url":"franz.html#ClientConfig"},{"doc":"franz","title":"Compression","content":"pub type Compression {\n  NoCompression\n  Gzip\n  Snappy\n}\n\nNoCompression\n\n\nGzip\n\n\nSnappy\n\n\nSynonyms:\nfranz.Compression\nfranz Compression","url":"franz.html#Compression"},{"doc":"franz","title":"FranzClient","content":"pub type FranzClient\n\n\nSynonyms:\nfranz.FranzClient\nfranz FranzClient","url":"franz.html#FranzClient"},{"doc":"franz","title":"FranzError","content":"pub type FranzError {\n  UnknownError\n  ClientDown\n  UnknownTopicOrPartition\n  ProducerDown\n  TopicAlreadyExists\n  ConsumerNotFound(String)\n  ProducerNotFound(String, Int)\n}\n\nUnknownError\n\n\nClientDown\n\n\nUnknownTopicOrPartition\n\n\nProducerDown\n\n\nTopicAlreadyExists\n\n\nConsumerNotFound(String)\n\n\nProducerNotFound(String, Int)\n\n\nSynonyms:\nfranz.FranzError\nfranz FranzError","url":"franz.html#FranzError"},{"doc":"franz","title":"KafkaMessage","content":"pub type KafkaMessage {\n  KafkaMessage(\n    offset: Int,\n    key: BitArray,\n    value: BitArray,\n    timestamp_type: TimeStampType,\n    timestamp: Int,\n    headers: List(#(String, String)),\n  )\n  KafkaMessageSet(\n    topic: Topic,\n    partition: Int,\n    high_wm_offset: Int,\n    messages: List(KafkaMessage),\n  )\n}\n\nKafkaMessage(\n  offset: Int,\n  key: BitArray,\n  value: BitArray,\n  timestamp_type: TimeStampType,\n  timestamp: Int,\n  headers: List(#(String, String)),\n)\n\n\nKafkaMessageSet(\n  topic: Topic,\n  partition: Int,\n  high_wm_offset: Int,\n  messages: List(KafkaMessage),\n)\n\n\nSynonyms:\nfranz.KafkaMessage\nfranz KafkaMessage","url":"franz.html#KafkaMessage"},{"doc":"franz","title":"Offset","content":"pub type Offset =\n  Int\n\n\nSynonyms:\nfranz.Offset\nfranz Offset","url":"franz.html#Offset"},{"doc":"franz","title":"Partition","content":"pub type Partition =\n  Int\n\n\nSynonyms:\nfranz.Partition\nfranz Partition","url":"franz.html#Partition"},{"doc":"franz","title":"ProducerConfig","content":"pub type ProducerConfig {\n  RequiredAcks(Int)\n  AckTimeout(Int)\n  PartitionBufferLimit(Int)\n  PartitionOnwireLimit(Int)\n  MaxBatchSize(Int)\n  MaxRetries(Int)\n  RetryBackoffMs(Int)\n  Compression(Compression)\n  MaxLingerMs(Int)\n  MaxLingerCount(Int)\n}\n\nRequiredAcks(Int)\n\n\nAckTimeout(Int)\n\n\nPartitionBufferLimit(Int)\n\n\nPartitionOnwireLimit(Int)\n\n\nMaxBatchSize(Int)\n\n\nMaxRetries(Int)\n\n\nRetryBackoffMs(Int)\n\n\nCompression(Compression)\n\n\nMaxLingerMs(Int)\n\n\nMaxLingerCount(Int)\n\n\nSynonyms:\nfranz.ProducerConfig\nfranz ProducerConfig","url":"franz.html#ProducerConfig"},{"doc":"franz","title":"TimeStampType","content":"pub type TimeStampType {\n  Undefined\n  Create\n  Append\n}\n\nUndefined\n\n\nCreate\n\n\nAppend\n\n\nSynonyms:\nfranz.TimeStampType\nfranz TimeStampType","url":"franz.html#TimeStampType"},{"doc":"franz","title":"Topic","content":"pub type Topic =\n  String\n\n\nSynonyms:\nfranz.Topic\nfranz Topic","url":"franz.html#Topic"},{"doc":"franz","title":"create_topic","content":"pub fn create_topic(\n  bootstrap_endpoints: List(#(String, Int)),\n  topic: String,\n  partitions: Int,\n  replication_factor: Int,\n) -&gt; Result(Nil, FranzError)\n\nSynonyms:\nfranz.create_topic\nfranz create_topic","url":"franz.html#create_topic"},{"doc":"franz","title":"fetch","content":"pub fn fetch(\n  client: FranzClient,\n  topic: String,\n  partition: Int,\n  offset: Int,\n) -&gt; Result(#(Int, KafkaMessage), FranzError)\n\nSynonyms:\nfranz.fetch\nfranz fetch","url":"franz.html#fetch"},{"doc":"franz","title":"start_client","content":"pub fn start_client(\n  bootstrap_endpoints: List(#(String, Int)),\n  client_config: List(ClientConfig),\n) -&gt; Result(FranzClient, FranzError)\n\nSynonyms:\nfranz.start_client\nfranz start_client","url":"franz.html#start_client"},{"doc":"franz","title":"stop_client","content":"pub fn stop_client(client: FranzClient) -&gt; Nil\n\nSynonyms:\nfranz.stop_client\nfranz stop_client","url":"franz.html#stop_client"},{"doc":"franz","title":"franz","content":"","url":"franz.html"},{"doc":"franz/consumers","title":"Ack","content":"pub type Ack\n\n\nSynonyms:\nfranz/consumers.Ack\nfranz/consumers Ack","url":"franz/consumers.html#Ack"},{"doc":"franz/consumers","title":"AckOrCommit","content":"pub type AckOrCommit(ack_or_commit)\n\n\nSynonyms:\nfranz/consumers.AckOrCommit\nfranz/consumers AckOrCommit","url":"franz/consumers.html#AckOrCommit"},{"doc":"franz/consumers","title":"Commit","content":"pub type Commit\n\n\nSynonyms:\nfranz/consumers.Commit\nfranz/consumers Commit","url":"franz/consumers.html#Commit"},{"doc":"franz/consumers","title":"CommitedOffset","content":"pub type CommitedOffset {\n  CommitedOffset(partition: Int, offset: Int)\n}\n\nCommitedOffset(partition: Int, offset: Int)\n\n\nSynonyms:\nfranz/consumers.CommitedOffset\nfranz/consumers CommitedOffset","url":"franz/consumers.html#CommitedOffset"},{"doc":"franz/consumers","title":"ConsumerConfig","content":"pub type ConsumerConfig {\n  BeginOffset(OffsetTime)\n  MinBytes(Int)\n  MaxBytes(Int)\n  MaxWaitTime(Int)\n  SleepTimeout(Int)\n  PrefetchCount(Int)\n  PrefetchBytes(Int)\n  OffsetResetPolicy(OffsetResetPolicy)\n  SizeStatWindow(Int)\n  IsolationLevel(IsolationLevel)\n  ShareLeaderConn(Bool)\n}\n\nBeginOffset(OffsetTime)\n\n\nMinBytes(Int)\n\n\nMaxBytes(Int)\n\n\nMaxWaitTime(Int)\n\n\nSleepTimeout(Int)\n\n\nPrefetchCount(Int)\n\n\nPrefetchBytes(Int)\n\n\nOffsetResetPolicy(OffsetResetPolicy)\n\n\nSizeStatWindow(Int)\n\n\nIsolationLevel(IsolationLevel)\n\n\nShareLeaderConn(Bool)\n\n\nSynonyms:\nfranz/consumers.ConsumerConfig\nfranz/consumers ConsumerConfig","url":"franz/consumers.html#ConsumerConfig"},{"doc":"franz/consumers","title":"ConsumerPartition","content":"pub type ConsumerPartition {\n  ConsumerPartitions(List(Int))\n  All\n}\n\nConsumerPartitions(List(Int))\n\n\nAll\n\n\nSynonyms:\nfranz/consumers.ConsumerPartition\nfranz/consumers ConsumerPartition","url":"franz/consumers.html#ConsumerPartition"},{"doc":"franz/consumers","title":"GroupConfig","content":"pub type GroupConfig {\n  SessionTimeoutSeconds(Int)\n  RebalanceTimeoutSeconds(Int)\n  HeartbeatRateSeconds(Int)\n  MaxRejoinAttempts(Int)\n  RejoinDelaySeconds(Int)\n  OffsetCommitIntervalSeconds(Int)\n  OffsetRetentionSeconds(Int)\n}\n\nSessionTimeoutSeconds(Int)\n\n\nRebalanceTimeoutSeconds(Int)\n\n\nHeartbeatRateSeconds(Int)\n\n\nMaxRejoinAttempts(Int)\n\n\nRejoinDelaySeconds(Int)\n\n\nOffsetCommitIntervalSeconds(Int)\n\n\nOffsetRetentionSeconds(Int)\n\n\nSynonyms:\nfranz/consumers.GroupConfig\nfranz/consumers GroupConfig","url":"franz/consumers.html#GroupConfig"},{"doc":"franz/consumers","title":"IsolationLevel","content":"pub type IsolationLevel {\n  ReadCommitted\n  ReadUncommitted\n}\n\nReadCommitted\n\n\nReadUncommitted\n\n\nSynonyms:\nfranz/consumers.IsolationLevel\nfranz/consumers IsolationLevel","url":"franz/consumers.html#IsolationLevel"},{"doc":"franz/consumers","title":"MessageType","content":"pub type MessageType {\n  Message\n  MessageSet\n}\n\nMessage\n\n\nMessageSet\n\n\nSynonyms:\nfranz/consumers.MessageType\nfranz/consumers MessageType","url":"franz/consumers.html#MessageType"},{"doc":"franz/consumers","title":"OffsetResetPolicy","content":"pub type OffsetResetPolicy {\n  ResetBySubscriber\n  ResetToEarliest\n  ResetToLatest\n}\n\nResetBySubscriber\n\n\nResetToEarliest\n\n\nResetToLatest\n\n\nSynonyms:\nfranz/consumers.OffsetResetPolicy\nfranz/consumers OffsetResetPolicy","url":"franz/consumers.html#OffsetResetPolicy"},{"doc":"franz/consumers","title":"OffsetTime","content":"pub type OffsetTime {\n  Earliest\n  Latest\n  MessageTimestamp(Int)\n}\n\nEarliest\n\n\nLatest\n\n\nMessageTimestamp(Int)\n\n\nSynonyms:\nfranz/consumers.OffsetTime\nfranz/consumers OffsetTime","url":"franz/consumers.html#OffsetTime"},{"doc":"franz/consumers","title":"ack_return","content":"pub fn ack_return(cb_state: a) -&gt; AckOrCommit(Ack)\n\nSynonyms:\nfranz/consumers.ack_return\nfranz/consumers ack_return","url":"franz/consumers.html#ack_return"},{"doc":"franz/consumers","title":"commit_return","content":"pub fn commit_return(cb_state: a) -&gt; AckOrCommit(Commit)\n\nSynonyms:\nfranz/consumers.commit_return\nfranz/consumers commit_return","url":"franz/consumers.html#commit_return"},{"doc":"franz/consumers","title":"start_consumer","content":"pub fn start_consumer(\n  client: FranzClient,\n  topic: String,\n  options: List(ConsumerConfig),\n) -&gt; Result(Nil, FranzError)\n\nSynonyms:\nfranz/consumers.start_consumer\nfranz/consumers start_consumer","url":"franz/consumers.html#start_consumer"},{"doc":"franz/consumers","title":"start_group_subscriber","content":"pub fn start_group_subscriber(\n  client: FranzClient,\n  group_id: String,\n  topics: List(String),\n  consumer_config: List(ConsumerConfig),\n  group_config: List(GroupConfig),\n  message_type: MessageType,\n  callback: fn(KafkaMessage, a) -&gt; AckOrCommit(b),\n  init_callback_state: a,\n) -&gt; Result(Pid, FranzError)\n\nSynonyms:\nfranz/consumers.start_group_subscriber\nfranz/consumers start_group_subscriber","url":"franz/consumers.html#start_group_subscriber"},{"doc":"franz/consumers","title":"start_topic_subscriber","content":"pub fn start_topic_subscriber(\n  client: FranzClient,\n  topic: String,\n  partitions: ConsumerPartition,\n  consumer_config: List(ConsumerConfig),\n  commited_offsets: List(CommitedOffset),\n  message_type: MessageType,\n  callback: fn(Int, KafkaMessage, a) -&gt; AckOrCommit(Ack),\n  init_callback_state: a,\n) -&gt; Result(Pid, FranzError)\n\nSynonyms:\nfranz/consumers.start_topic_subscriber\nfranz/consumers start_topic_subscriber","url":"franz/consumers.html#start_topic_subscriber"},{"doc":"franz/consumers","title":"franz/consumers","content":"","url":"franz/consumers.html"},{"doc":"franz/producers","title":"Partitioner","content":"pub type Partitioner {\n  PartitionFun(\n    fn(String, Int, BitArray, BitArray) -&gt; Result(Int, Nil),\n  )\n  Random\n  Hash\n}\n\nPartitionFun(\n  fn(String, Int, BitArray, BitArray) -&gt; Result(Int, Nil),\n)\n\n\nRandom\n\n\nHash\n\n\nSynonyms:\nfranz/producers.Partitioner\nfranz/producers Partitioner","url":"franz/producers.html#Partitioner"},{"doc":"franz/producers","title":"ProducerPartition","content":"pub type ProducerPartition {\n  Partition(Int)\n  Partitioner(Partitioner)\n}\n\nPartition(Int)\n\n\nPartitioner(Partitioner)\n\n\nSynonyms:\nfranz/producers.ProducerPartition\nfranz/producers ProducerPartition","url":"franz/producers.html#ProducerPartition"},{"doc":"franz/producers","title":"Value","content":"pub type Value {\n  Value(value: BitArray, headers: List(#(String, String)))\n  ValueWithTimestamp(\n    value: BitArray,\n    timestamp: Int,\n    headers: List(#(String, String)),\n  )\n}\n\nValue(value: BitArray, headers: List(#(String, String)))\n\n\nValueWithTimestamp(\n  value: BitArray,\n  timestamp: Int,\n  headers: List(#(String, String)),\n)\n\n\nSynonyms:\nfranz/producers.Value\nfranz/producers Value","url":"franz/producers.html#Value"},{"doc":"franz/producers","title":"produce","content":"pub fn produce(\n  client: FranzClient,\n  topic: String,\n  partition: ProducerPartition,\n  key: BitArray,\n  value: Value,\n) -&gt; Result(Nil, FranzError)\n\nSynonyms:\nfranz/producers.produce\nfranz/producers produce","url":"franz/producers.html#produce"},{"doc":"franz/producers","title":"produce_cb","content":"pub fn produce_cb(\n  client: FranzClient,\n  topic: String,\n  partition: ProducerPartition,\n  key: BitArray,\n  value: Value,\n  callback: fn(Int, Int) -&gt; a,\n) -&gt; Result(Int, FranzError)\n\nSynonyms:\nfranz/producers.produce_cb\nfranz/producers produce_cb","url":"franz/producers.html#produce_cb"},{"doc":"franz/producers","title":"produce_sync","content":"pub fn produce_sync(\n  client: FranzClient,\n  topic: String,\n  partition: ProducerPartition,\n  key: BitArray,\n  value: Value,\n) -&gt; Result(Nil, FranzError)\n\nSynonyms:\nfranz/producers.produce_sync\nfranz/producers produce_sync","url":"franz/producers.html#produce_sync"},{"doc":"franz/producers","title":"produce_sync_offset","content":"pub fn produce_sync_offset(\n  client: FranzClient,\n  topic: String,\n  partition: ProducerPartition,\n  key: BitArray,\n  value: Value,\n) -&gt; Result(Int, FranzError)\n\nSynonyms:\nfranz/producers.produce_sync_offset\nfranz/producers produce_sync_offset","url":"franz/producers.html#produce_sync_offset"},{"doc":"franz/producers","title":"franz/producers","content":"","url":"franz/producers.html"}]);